@@ -1,4 +1,4 @@
-/*  $Id: xfce_theme_draw.c,v 1.20 2005/01/01 19:35:14 olivier Exp $
+/*  $Id: xfce_theme_draw.c 400 2005-03-09 21:24:56Z olivier $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -586,6 +586,11 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
 
                     gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x + 1, y + height - 1, x + width - 1, y + height - 1);
                     gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x + width - 1, y + 1, x + width - 1, y + height - 1);
+
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y + height - 1);
                 }
                 else if ((xt > 1) && (yt > 1))
                 {
@@ -657,10 +662,60 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
         case GTK_SHADOW_OUT:
             if(XFCE_RC_STYLE(style->rc_style)->smooth_edge)
             {
-                if ((DETAIL("spinbutton_up") || DETAIL("spinbutton_down")) && (state_type != GTK_STATE_PRELIGHT))
+                if ((DETAIL("spinbutton_up") || DETAIL("spinbutton_up") || DETAIL("spinbutton_down")) && (state_type != GTK_STATE_PRELIGHT))
                 {
                     /* Do nothing */
                 }
+                else if (DETAIL("bar"))
+                {
+                    gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 1, y);
+                    gdk_draw_line(window, style->dark_gc[state_type], x, y, x, y + height - 1);
+
+                    gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->dark_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 1);
+
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y + height - 1);
+                    gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y + height - 1);
+                }
+                else if (DETAIL("menu"))
+                {
+                    if ((xt > 0) && (yt > 0))
+                    {
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 1, y);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y, x, y + height - 1);
+
+                        gdk_draw_line(window, style->dark_gc[state_type], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                        gdk_draw_line(window, style->dark_gc[state_type], x + width - 1, y + 1, x + width - 1, y + height - 1);
+                    }
+                }
+                else if (DETAIL("menubar"))
+                {
+                    if ((xt > 1) && (yt > 1))
+                    {
+                        gdk_draw_line(window, style->mid_gc[state_type], x , y + height - 2, x + width - 1, y + height - 2);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                    else if ((xt > 0) && (yt > 0))
+                    {
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                }
+                else if (DETAIL ("dockitem_bin") || DETAIL ("dockitem") || DETAIL ("toolbar"))
+                {
+                    if ((xt > 1) && (yt > 1))
+                    {
+                        gdk_draw_line(window, style->light_gc[state_type], x, y, x + width - 1, y);
+                        gdk_draw_line(window, style->mid_gc[state_type], x , y + height - 2, x + width - 1, y + height - 2);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                    else if ((xt > 0) && (yt > 0))
+                    {
+                        gdk_draw_line(window, style->light_gc[state_type], x, y, x + width - 1, y);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                }
                 else if(DETAIL("vscrollbar") || DETAIL("hscrollbar") || DETAIL("bar") || DETAIL("slider") || DETAIL("vscale") || DETAIL("hscale"))
                 {
                     if ((xt > 1) && (yt > 1))
@@ -753,6 +808,36 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
                 {
                     /* Do nothing */
                 }
+                if ((DETAIL("spinbutton_up") || DETAIL("spinbutton_down")) && (state_type != GTK_STATE_PRELIGHT))
+                {
+                    /* Do nothing */
+                }
+                else if (DETAIL("menubar"))
+                {
+                    if ((xt > 1) && (yt > 1))
+                    {
+                        gdk_draw_line(window, style->mid_gc[state_type], x , y + height - 2, x + width - 1, y + height - 2);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                    else if ((xt > 0) && (yt > 0))
+                    {
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                }
+                else if (DETAIL ("dockitem_bin") || DETAIL ("dockitem") || DETAIL ("toolbar"))
+                {
+                    if ((xt > 1) && (yt > 1))
+                    {
+                        gdk_draw_line(window, style->light_gc[state_type], x, y, x + width - 1, y);
+                        gdk_draw_line(window, style->mid_gc[state_type], x , y + height - 2, x + width - 1, y + height - 2);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                    else if ((xt > 0) && (yt > 0))
+                    {
+                        gdk_draw_line(window, style->light_gc[state_type], x, y, x + width - 1, y);
+                        gdk_draw_line(window, style->dark_gc[state_type], x, y + height - 1, x + width - 1, y + height - 1);
+                    }
+                }
                 else if ((xt > 1) && (yt > 1))
                 {
                     gdk_draw_line(window, style->dark_gc[state_type], x, y, x + width - 1, y);
@@ -1255,7 +1340,9 @@ static void draw_handle(GtkStyle * style, GdkWindow * window, GtkStateType state
     if(height > width)
         orientation = GTK_ORIENTATION_VERTICAL;
 
+#if 0
     draw_box(style, window, state_type, shadow_type, area, widget, detail, x, y, width, height);
+#endif
     xfce_draw_grips(style, window, state_type, area, widget, x, y, width, height, orientation);
 }
 
